Index: trunk/XTIDE_Universal_BIOS_Configurator_v2/Inc/MenuStructs.inc
===================================================================
--- trunk/XTIDE_Universal_BIOS_Configurator_v2/Inc/MenuStructs.inc	(revision 107)
+++ trunk/XTIDE_Universal_BIOS_Configurator_v2/Inc/MenuStructs.inc	(revision 108)
@@ -1,7 +1,3 @@
-; File name		:	MenuStructs.inc
 ; Project name	:	XTIDE Universal BIOS Configurator v2
-; Created date	:	5.10.2010
-; Last update	:	18.11.2010
-; Author		:	Tomi Tilli
 ; Description	:	Menu page and item structs.
 %ifndef MENU_STRUCTS_INC
@@ -39,5 +35,5 @@
 TYPE_MENUITEM_PAGENEXT		EQU	(1<<1)	; Item changes to next MENUPAGE
 TYPE_MENUITEM_ACTION		EQU	(2<<1)	; Non-configurable item
-TYPE_MENUITEM_MULTICHOISE	EQU	(3<<1)	; Item with multiple predefined choises
+TYPE_MENUITEM_MULTICHOICE	EQU	(3<<1)	; Item with multiple predefined choices
 TYPE_MENUITEM_UNSIGNED		EQU	(4<<1)	; Menuitem with user inputted unsigned decimal value
 TYPE_MENUITEM_HEX			EQU	(5<<1)	; Menuitem with user inputted hexadecimal value
@@ -48,6 +44,6 @@
 	.szDialogTitle			resb	2	; Dialog title string
 
-	.szMultichoise			resb	2	; Multiple choises in one string
-	.rgwChoiseToValueLookup	resb	2	; Ptr to lookup table for translating selected choise to actual value
+	.szMultichoice			resb	2	; Multiple choices in one string
+	.rgwChoiceToValueLookup	resb	2	; Ptr to lookup table for translating selected choice to actual value
 	.rgszValueToStringLookup:			; Ptr to lookup table for translating value to string
 	.wMinValue				resb	2	; Minimum allowed integer value
Index: trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Dialogs.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Dialogs.asm	(revision 107)
+++ trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Dialogs.asm	(revision 108)
@@ -1,7 +1,3 @@
-; File name		:	Dialogs.asm
 ; Project name	:	XTIDE Univeral BIOS Configurator v2
-; Created date	:	10.10.2010
-; Last update	:	2.12.2010
-; Author		:	Tomi Tilli
 ; Description	:	Functions for displaying dialogs.
 
@@ -129,5 +125,5 @@
 	call	InitializeDialogInputFromDSSI
 	mov		WORD [si+DIALOG_INPUT.fszTitle], g_szDlgExitToDos
-	mov		WORD [si+DIALOG_INPUT.fszItems], g_szMultichoiseBooleanFlag
+	mov		WORD [si+DIALOG_INPUT.fszItems], g_szMultichoiceBooleanFlag
 	CALL_MENU_LIBRARY GetSelectionToAXwithInputInDSSI
 	add		sp, BYTE DIALOG_INPUT_size
@@ -146,5 +142,5 @@
 	call	InitializeDialogInputFromDSSI
 	mov		WORD [si+DIALOG_INPUT.fszTitle], g_szDlgSaveChanges
-	mov		WORD [si+DIALOG_INPUT.fszItems], g_szMultichoiseBooleanFlag
+	mov		WORD [si+DIALOG_INPUT.fszItems], g_szMultichoiceBooleanFlag
 	CALL_MENU_LIBRARY GetSelectionToAXwithInputInDSSI
 	add		sp, BYTE DIALOG_INPUT_size
Index: trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/BootMenuSettingsMenu.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/BootMenuSettingsMenu.asm	(revision 107)
+++ trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/BootMenuSettingsMenu.asm	(revision 108)
@@ -1,7 +1,3 @@
-; File name		:	BootMenuSettingsMenu.asm
 ; Project name	:	XTIDE Universal BIOS Configurator v2
-; Created date	:	18.11.2010
-; Last update	:	18.11.2010
-; Author		:	Tomi Tilli
 ; Description	:	"Boot Menu Settings" menu structs and functions.
 
@@ -44,5 +40,5 @@
 g_MenuitemBootMnuStngsDisplayRomBoot:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemBootRomBoot
@@ -50,8 +46,8 @@
 	at	MENUITEM.szHelp,			dw	g_szHelpBootRomBoot
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_VISIBLE | FLG_MENUITEM_FLAGVALUE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	ROMVARS.wFlags
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgBootRomBoot
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseBooleanFlag
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceBooleanFlag
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForFlagBooleans
 	at	MENUITEM.itemValue + ITEM_VALUE.wValueBitmask,				dw	FLG_ROMVARS_ROMBOOT
@@ -60,5 +56,5 @@
 g_MenuitemBootMnuStngsFloppyDrives:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromUnshiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemBootFloppyDrvs
@@ -66,9 +62,9 @@
 	at	MENUITEM.szHelp,			dw	g_szHelpBootFloppyDrvs
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_VISIBLE | FLG_MENUITEM_BYTEVALUE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	ROMVARS.bMinFddCnt
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgBootFloppyDrvs
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseBootFloppyDrvs
-	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiseToValueLookup,		dw	g_rgwChoiseToValueLookupForFloppyDrives
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceBootFloppyDrvs
+	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiceToValueLookup,		dw	g_rgwChoiceToValueLookupForFloppyDrives
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForFloppyDrives
 iend
@@ -91,5 +87,5 @@
 g_MenuitemBootMnuStngsSwapBootDriveNumbers:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemBootSwap
@@ -97,13 +93,13 @@
 	at	MENUITEM.szHelp,			dw	g_szHelpBootSwap
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_VISIBLE | FLG_MENUITEM_FLAGVALUE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	ROMVARS.wFlags
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgBootSwap
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseBooleanFlag
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceBooleanFlag
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForFlagBooleans
 	at	MENUITEM.itemValue + ITEM_VALUE.wValueBitmask,				dw	FLG_ROMVARS_DRVXLAT
 iend
 
-g_rgwChoiseToValueLookupForFloppyDrives:	; (No translation)
+g_rgwChoiceToValueLookupForFloppyDrives:	; (No translation)
 	dw	0
 	dw	1
Index: trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/ConfigurationMenu.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/ConfigurationMenu.asm	(revision 107)
+++ trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/ConfigurationMenu.asm	(revision 108)
@@ -1,7 +1,3 @@
-; File name		:	ConfigurationMenu.asm
 ; Project name	:	XTIDE Universal BIOS Configurator v2
-; Created date	:	24.10.2010
-; Last update	:	18.11.2010
-; Author		:	Tomi Tilli
 ; Description	:	"Configure XTIDE Universal BIOS" menu structs and functions.
 
@@ -89,5 +85,5 @@
 g_MenuitemConfigurationBootLoaderType:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemCfgBootLoader
@@ -95,9 +91,9 @@
 	at	MENUITEM.szHelp,			dw	g_szNfoCfgBootLoader
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_VISIBLE | FLG_MENUITEM_MODIFY_MENU | FLG_MENUITEM_BYTEVALUE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	ROMVARS.bBootLdrType
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szItemCfgBootLoader
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseCfgBootLoader
-	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiseToValueLookup,		dw	g_rgwChoiseToValueLookupForBootLoaderType
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceCfgBootLoader
+	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiceToValueLookup,		dw	g_rgwChoiceToValueLookupForBootLoaderType
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForBootLoaderType
 iend
@@ -105,5 +101,5 @@
 g_MenuitemConfigurationFullOperatingMode:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemCfgFullMode
@@ -111,8 +107,8 @@
 	at	MENUITEM.szHelp,			dw	g_szHelpCfgFullMode
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_VISIBLE | FLG_MENUITEM_MODIFY_MENU | FLG_MENUITEM_FLAGVALUE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	ROMVARS.wFlags
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgCfgFullMode
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseBooleanFlag
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceBooleanFlag
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForFlagBooleans
 	at	MENUITEM.itemValue + ITEM_VALUE.wValueBitmask,				dw	FLG_ROMVARS_FULLMODE
@@ -150,5 +146,5 @@
 
 
-g_rgwChoiseToValueLookupForBootLoaderType:
+g_rgwChoiceToValueLookupForBootLoaderType:
 	dw	BOOTLOADER_TYPE_MENU
 	dw	BOOTLOADER_TYPE_SIMPLE
@@ -159,5 +155,5 @@
 	dw	g_szUnidentified
 	dw	g_szValueCfgBootLoaderSystem
-	
+
 
 ; Section containing code
Index: trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/FlashMenu.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/FlashMenu.asm	(revision 107)
+++ trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/FlashMenu.asm	(revision 108)
@@ -1,7 +1,3 @@
-; File name		:	FlashMenu.asm
 ; Project name	:	XTIDE Universal BIOS Configurator v2
-; Created date	:	19.11.2010
-; Last update	:	19.12.2010
-; Author		:	Tomi Tilli
 ; Description	:	"Flash EEPROM" menu structs and functions.
 
@@ -39,5 +35,5 @@
 g_MenuitemFlashEepromType:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemFlashEepromType
@@ -45,9 +41,9 @@
 	at	MENUITEM.szHelp,			dw	g_szNfoFlashEepromType
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_PROGRAMVAR | FLG_MENUITEM_BYTEVALUE | FLG_MENUITEM_VISIBLE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	CFGVARS.bEepromType
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgFlashEepromType
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseEepromType
-	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiseToValueLookup,		dw	g_rgwChoiseToValueLookupForEepromType
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceEepromType
+	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiceToValueLookup,		dw	g_rgwChoiceToValueLookupForEepromType
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForEepromType
 iend
@@ -55,5 +51,5 @@
 g_MenuitemFlashSdpCommand:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemFlashSDP
@@ -61,9 +57,9 @@
 	at	MENUITEM.szHelp,			dw	g_szHelpFlashSDP
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_PROGRAMVAR | FLG_MENUITEM_BYTEVALUE | FLG_MENUITEM_VISIBLE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	CFGVARS.bSdpCommand
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgFlashSDP
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseSdpCommand
-	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiseToValueLookup,		dw	g_rgwChoiseToValueLookupForSdpCommand
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceSdpCommand
+	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiceToValueLookup,		dw	g_rgwChoiceToValueLookupForSdpCommand
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForSdpCommand
 iend
@@ -71,5 +67,5 @@
 g_MenuitemFlashPageSize:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemFlashPageSize
@@ -77,9 +73,9 @@
 	at	MENUITEM.szHelp,			dw	g_szHelpFlashPageSize
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_PROGRAMVAR | FLG_MENUITEM_BYTEVALUE | FLG_MENUITEM_VISIBLE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	CFGVARS.bEepromPage
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgFlashPageSize
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoisePageSize
-	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiseToValueLookup,		dw	g_rgwChoiseToValueLookupForPageSize
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoicePageSize
+	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiceToValueLookup,		dw	g_rgwChoiceToValueLookupForPageSize
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForPageSize
 iend
@@ -102,5 +98,5 @@
 g_MenuitemFlashGenerateChecksum:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemFlashChecksum
@@ -108,13 +104,13 @@
 	at	MENUITEM.szHelp,			dw	g_szHelpFlashChecksum
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_PROGRAMVAR | FLG_MENUITEM_VISIBLE | FLG_MENUITEM_FLAGVALUE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	CFGVARS.wFlags
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgFlashChecksum
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseBooleanFlag
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceBooleanFlag
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForFlagBooleans
 	at	MENUITEM.itemValue + ITEM_VALUE.wValueBitmask,				dw	FLG_CFGVARS_CHECKSUM
 iend
 
-g_rgwChoiseToValueLookupForEepromType:
+g_rgwChoiceToValueLookupForEepromType:
 	dw	EEPROM_TYPE.2816_2kiB
 	dw	EEPROM_TYPE.2864_8kiB
@@ -127,5 +123,5 @@
 	dw	g_szValueFlash28512
 
-g_rgwChoiseToValueLookupForSdpCommand:
+g_rgwChoiceToValueLookupForSdpCommand:
 	dw	SDP_COMMAND.none
 	dw	SDP_COMMAND.enable
@@ -136,5 +132,5 @@
 	dw	g_szValueFlashDisable
 
-g_rgwChoiseToValueLookupForPageSize:
+g_rgwChoiceToValueLookupForPageSize:
 	dw	EEPROM_PAGE.1_byte
 	dw	EEPROM_PAGE.2_bytes
Index: trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/IdeControllerMenu.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/IdeControllerMenu.asm	(revision 107)
+++ trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/IdeControllerMenu.asm	(revision 108)
@@ -1,7 +1,3 @@
-; File name		:	IdeControllerMenu.asm
 ; Project name	:	XTIDE Universal BIOS Configurator v2
-; Created date	:	2.11.2010
-; Last update	:	18.11.2010
-; Author		:	Tomi Tilli
 ; Description	:	"IDE Controller" menu structs and functions.
 
@@ -49,5 +45,5 @@
 g_MenuitemIdeControllerBusType:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemIdeBusType
@@ -55,9 +51,9 @@
 	at	MENUITEM.szHelp,			dw	g_szNfoIdeBusType
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_VISIBLE | FLG_MENUITEM_BYTEVALUE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	NULL
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgBusType
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseCfgBusType
-	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiseToValueLookup,		dw	g_rgwChoiseToValueLookupForBusType
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceCfgBusType
+	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiceToValueLookup,		dw	g_rgwChoiceToValueLookupForBusType
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForBusType
 iend
@@ -95,5 +91,5 @@
 g_MenuitemIdeControllerEnableInterrupt:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemIdeEnIRQ
@@ -101,8 +97,8 @@
 	at	MENUITEM.szHelp,			dw	g_szHelpIdeEnIRQ
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_VISIBLE | FLG_MENUITEM_MODIFY_MENU | FLG_MENUITEM_FLAGVALUE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	NULL
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgIdeEnIRQ
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseBooleanFlag
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceBooleanFlag
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForFlagBooleans
 	at	MENUITEM.itemValue + ITEM_VALUE.wValueBitmask,				dw	15
@@ -124,5 +120,5 @@
 iend
 
-g_rgwChoiseToValueLookupForBusType:
+g_rgwChoiceToValueLookupForBusType:
 	dw	BUS_TYPE_8_DUAL
 	dw	BUS_TYPE_8_SINGLE
Index: trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/MainMenu.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/MainMenu.asm	(revision 107)
+++ trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/MainMenu.asm	(revision 108)
@@ -1,7 +1,3 @@
-; File name		:	MainMenu.asm
 ; Project name	:	XTIDE Universal BIOS Configurator v2
-; Created date	:	6.10.2010
-; Last update	:	9.12.2010
-; Author		:	Tomi Tilli
 ; Description	:	Main menu structs and functions.
 
@@ -89,6 +85,6 @@
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	NULL
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	NULL
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	NULL
-	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiseToValueLookup,		dw	NULL
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	NULL
+	at	MENUITEM.itemValue + ITEM_VALUE.rgwChoiceToValueLookup,		dw	NULL
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	NULL
 	at	MENUITEM.itemValue + ITEM_VALUE.wMinValue,					dw	NULL
Index: trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/MasterSlaveMenu.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/MasterSlaveMenu.asm	(revision 107)
+++ trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menupages/MasterSlaveMenu.asm	(revision 108)
@@ -1,7 +1,3 @@
-; File name		:	MasterSlaveMenu.asm
 ; Project name	:	XTIDE Universal BIOS Configurator v2
-; Created date	:	3.11.2010
-; Last update	:	18.11.2010
-; Author		:	Tomi Tilli
 ; Description	:	"Master/Slave Drive" menu structs and functions.
 
@@ -29,5 +25,5 @@
 g_MenuitemMasterSlaveBlockModeTransfers:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemDrvBlockMode
@@ -35,8 +31,8 @@
 	at	MENUITEM.szHelp,			dw	g_szHelpDrvBlockMode
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_VISIBLE | FLG_MENUITEM_FLAGVALUE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	NULL
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgDrvBlockMode
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseBooleanFlag
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceBooleanFlag
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForFlagBooleans
 	at	MENUITEM.itemValue + ITEM_VALUE.wValueBitmask,				dw	FLG_DRVPARAMS_BLOCKMODE
@@ -45,5 +41,5 @@
 g_MenuitemMasterSlaveUserCHS:
 istruc MENUITEM
-	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+	at	MENUITEM.fnActivate,		dw	Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 	at	MENUITEM.fnFormatValue,		dw	MenuitemPrint_WriteLookupValueStringToBufferInESDIfromShiftedItemInDSSI
 	at	MENUITEM.szName,			dw	g_szItemDrvUserCHS
@@ -51,8 +47,8 @@
 	at	MENUITEM.szHelp,			dw	g_szHelpDrvUserCHS
 	at	MENUITEM.bFlags,			db	FLG_MENUITEM_VISIBLE | FLG_MENUITEM_MODIFY_MENU | FLG_MENUITEM_FLAGVALUE
-	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOISE
+	at	MENUITEM.bType,				db	TYPE_MENUITEM_MULTICHOICE
 	at	MENUITEM.itemValue + ITEM_VALUE.wRomvarsValueOffset,		dw	NULL
 	at	MENUITEM.itemValue + ITEM_VALUE.szDialogTitle,				dw	g_szDlgDrvUserCHS
-	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoise,				dw	g_szMultichoiseBooleanFlag
+	at	MENUITEM.itemValue + ITEM_VALUE.szMultichoice,				dw	g_szMultichoiceBooleanFlag
 	at	MENUITEM.itemValue + ITEM_VALUE.rgszValueToStringLookup,	dw	g_rgszValueToStringLookupForFlagBooleans
 	at	MENUITEM.itemValue + ITEM_VALUE.wValueBitmask,				dw	FLG_DRVPARAMS_USERCHS
Index: trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Strings.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Strings.asm	(revision 107)
+++ trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Strings.asm	(revision 108)
@@ -1,9 +1,4 @@
-; File name		:	Strings.asm
 ; Project name	:	XTIDE Universal BIOS Configurator v2
-; Created date	:	5.10.2010
-; Last update	:	9.12.2010
-; Author		:	Tomi Tilli
 ; Description	:	All strings.
-
 
 ; Section containing initialized data
@@ -20,5 +15,5 @@
 g_szUnsaved:						db	" ",SINGLE_LEFT_HORIZONTAL_TO_VERTICAL,
 									db	"Unsaved",SINGLE_RIGHT_HORIZONTAL_TO_VERTICAL, NULL
-									
+
 ; Item formatting
 g_szFormatItemWithoutValue:			db	"%c%s",NULL
@@ -28,5 +23,5 @@
 g_szNo:								db	"No",NULL
 g_szYes:							db	"Yes",NULL
-g_szMultichoiseBooleanFlag:
+g_szMultichoiceBooleanFlag:
 									db	"No",LF
 									db	"Yes",NULL
@@ -108,5 +103,5 @@
 						db	NULL
 
-g_szMultichoiseCfgBootLoader:
+g_szMultichoiceCfgBootLoader:
 						db	"Boot menu",LF
 						db	"Drive A then C",LF
@@ -152,5 +147,5 @@
 						db	NULL
 
-g_szMultichoiseCfgBusType:
+g_szMultichoiceCfgBusType:
 						db	"8-bit dual port (XTIDE)",LF
 						db	"8-bit single port",LF
@@ -220,5 +215,5 @@
 						db	NULL
 
-g_szMultichoiseBootFloppyDrvs:
+g_szMultichoiceBootFloppyDrvs:
 						db	"Autodetect",LF
 						db	"1",LF
@@ -262,5 +257,5 @@
 						db	NULL
 
-g_szMultichoiseEepromType:
+g_szMultichoiceEepromType:
 						db	"2816 (2 kiB)",LF
 						db	"2864 (8 kiB)",LF
@@ -272,5 +267,5 @@
 g_szValueFlash28512:	db	"28512",NULL
 
-g_szMultichoiseSdpCommand:
+g_szMultichoiceSdpCommand:
 						db	"None",LF
 						db	"Enable",LF
@@ -280,5 +275,5 @@
 g_szValueFlashDisable:	db	"Disable",NULL
 
-g_szMultichoisePageSize:
+g_szMultichoicePageSize:
 						db	"1 byte",LF
 						db	"2 bytes",LF

Index: trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menuitem.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menuitem.asm	(revision 107)
+++ trunk/XTIDE_Universal_BIOS_Configurator_v2/Src/Menuitem.asm	(revision 108)
@@ -22,5 +22,5 @@
 
 ;--------------------------------------------------------------------
-; Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI
+; Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI
 ;	Parameters:
 ;		DS:SI:	Ptr to MENUITEM
@@ -31,5 +31,5 @@
 ;--------------------------------------------------------------------
 ALIGN JUMP_ALIGN
-Menuitem_ActivateMultichoiseSelectionForMenuitemInDSSI:
+Menuitem_ActivateMultichoiceSelectionForMenuitemInDSSI:
 	call	Registers_CopyDSSItoESDI
 
@@ -37,5 +37,5 @@
 	call	Memory_ReserveCXbytesFromStackToDSSI
 	call	InitializeDialogInputInDSSIfromMenuitemInESDI
-	mov		ax, [es:di+MENUITEM.itemValue + ITEM_VALUE.szMultichoise]
+	mov		ax, [es:di+MENUITEM.itemValue + ITEM_VALUE.szMultichoice]
 	mov		[si+DIALOG_INPUT.fszItems], ax
 	push	di
@@ -133,5 +133,5 @@
 ; Menuitem_StoreValueFromAXtoMenuitemInDSSI
 ;	Parameters:
 ;		AX:		Value or multichoise selection to store
 ;		DS:SI:	Ptr to MENUITEM
 ;		SS:BP:	Menu handle
@@ -158,12 +158,12 @@
 	dw		.InvalidItemType									; TYPE_MENUITEM_PAGENEXT
 	dw		.InvalidItemType									; TYPE_MENUITEM_ACTION
-	dw		.StoreMultichoiseValueFromAXtoESDIwithItemInDSSI	; TYPE_MENUITEM_MULTICHOISE
+	dw		.StoreMultichoiceValueFromAXtoESDIwithItemInDSSI	; TYPE_MENUITEM_MULTICHOICE
 	dw		.StoreByteOrWordValueFromAXtoESDIwithItemInDSSI		; TYPE_MENUITEM_UNSIGNED
 	dw		.StoreByteOrWordValueFromAXtoESDIwithItemInDSSI		; TYPE_MENUITEM_HEX
 
 ;--------------------------------------------------------------------
 ; .StoreMultichoiseValueFromAXtoESDIwithItemInDSSI
 ;	Parameters:
 ;		AX:		Multichoise selection (index)
 ;		DS:SI:	Ptr to MENUITEM
 ;		ES:DI:	Ptr to value variable
@@ -175,7 +175,7 @@
 ;--------------------------------------------------------------------
 ALIGN JUMP_ALIGN
-.StoreMultichoiseValueFromAXtoESDIwithItemInDSSI:
+.StoreMultichoiceValueFromAXtoESDIwithItemInDSSI:
 	test	BYTE [si+MENUITEM.bFlags], FLG_MENUITEM_FLAGVALUE
-	jz		SHORT .TranslateChoiseToValueUsingLookupTable
+	jz		SHORT .TranslateChoiceToValueUsingLookupTable
 
 	test	ax, ax			; Setting item flag?
@@ -191,7 +191,7 @@
 
 ALIGN JUMP_ALIGN
-.TranslateChoiseToValueUsingLookupTable:
+.TranslateChoiceToValueUsingLookupTable:
 	shl		ax, 1			; Shift for WORD lookup
-	add		ax, [si+MENUITEM.itemValue+ITEM_VALUE.rgwChoiseToValueLookup]
+	add		ax, [si+MENUITEM.itemValue+ITEM_VALUE.rgwChoiceToValueLookup]
 	xchg	bx, ax
 	mov		ax, [bx]		; Lookup complete
@@ -133,5 +133,5 @@
 ; Menuitem_StoreValueFromAXtoMenuitemInDSSI
 ;	Parameters:
-;		AX:		Value or multichoise selection to store
+;		AX:		Value or multichoice selection to store
 ;		DS:SI:	Ptr to MENUITEM
 ;		SS:BP:	Menu handle
@@ -158,12 +158,12 @@
 
 ;--------------------------------------------------------------------
-; .StoreMultichoiseValueFromAXtoESDIwithItemInDSSI
-;	Parameters:
-;		AX:		Multichoise selection (index)
+; .StoreMultichoiceValueFromAXtoESDIwithItemInDSSI
+;	Parameters:
+;		AX:		Multichoice selection (index)
 ;		DS:SI:	Ptr to MENUITEM
 ;		ES:DI:	Ptr to value variable